@@ -206,9 +206,7 @@ def run(context, input, filter, **kwargs):
 
     cases = (TestCase.from_dict(**json.loads(line)) for line in input)
     if filter:
-        cases = (
-            case for case in cases if fnmatch(case["description"], filter)
-        )
+        cases = (case for case in cases if fnmatch(case.description, filter))
 
     exit_code = asyncio.run(_run(**kwargs, cases=cases))
     context.exit(exit_code)
@@ -360,9 +358,7 @@ def suite(context, input, filter, **kwargs):
 
     cases, dialect = input
     if filter:
-        cases = (
-            case for case in cases if fnmatch(case["description"], filter)
-        )
+        cases = (case for case in cases if fnmatch(case.description, filter))
 
     exit_code = asyncio.run(_run(**kwargs, dialect=dialect, cases=cases))
     context.exit(exit_code)
@@ -377,13 +373,13 @@ async def _run(
     make_validator: callable,
     reporter: _report.Reporter = _report.Reporter(),
 ):
-    reporter.will_speak(dialect=dialect)
     acknowledged, runners, exit_code = [], [], 0
     async with _start(
         image_names=image_names,
         make_validator=make_validator,
         reporter=reporter,
     ) as starting:
+        reporter.will_speak(dialect=dialect)
         for each in asyncio.as_completed(starting):
             try:
                 implementation = await each
@@ -419,7 +415,12 @@ async def _run(
             exit_code = os.EX_CONFIG
             reporter.no_implementations()
         else:
-            reporter.ready(implementations=acknowledged, dialect=dialect)
+            reporter.ready(
+                _report.RunInfo.from_implementations(
+                    implementations=acknowledged,
+                    dialect=dialect,
+                ),
+            )
 
             seq = 0
             should_stop = False
@@ -471,7 +472,7 @@ def sequenced(cases, reporter):
 
 def suite_cases_from(files, remotes):
     for file in files:
-        if file.stem in {"refRemote", "dynamicRef", "vocabulary"}:
+        if _stem(file) in {"refRemote", "dynamicRef", "vocabulary"}:
             registry = {
                 urljoin(
                     "http://localhost:1234",
@@ -553,3 +554,9 @@ def _relative_to(path, other):
     if hasattr(path, "relative_to"):
         return path.relative_to(other)
     return Path(path.at).relative_to(other.at)
+
+
+def _stem(path):
+    if hasattr(path, "stem"):
+        return path.stem
+    return Path(path.at).stem
