@@ -95,7 +95,7 @@ async def bowtie(*args, succeed=True):
 
         if succeed:
             try:
-                RunInfo.from_header_lines(next(lines, None), next(lines))
+                RunInfo(**next(lines))
             except _InvalidBowtieReport:
                 pytest.fail(f"Invalid report, stderr contained: {stderr}")
         else:
@@ -315,6 +315,22 @@ async def test_fail_fast(envsonschema):
     assert returncode == 0, stderr
 
 
+@pytest.mark.asyncio
+async def test_filter(envsonschema):
+    async with bowtie("-i", envsonschema, "-k", "baz") as send:
+        returncode, results, _, _, stderr = await send(
+            """
+            {"description": "foo", "schema": {}, "tests": [{"description": "valid:1", "instance": {}, "valid": true}] }
+            {"description": "bar", "schema": {}, "tests": [{"description": "valid:0", "instance": 7, "valid": true}] }
+            {"description": "baz", "schema": {}, "tests": [{"description": "valid:1", "instance": {}, "valid": true}] }
+            """,  # noqa: E501
+        )
+
+    assert results == [[{"valid": True}]], stderr
+    assert stderr != ""
+    assert returncode == 0, stderr
+
+
 @pytest.mark.asyncio
 async def test_smoke(envsonschema):
     proc = await asyncio.create_subprocess_exec(
